/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.javable.cese.models;

import java.awt.Image;
import java.beans.BeanDescriptor;
import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.beans.SimpleBeanInfo;

public class LuoRudyModel_II_2000BeanInfo extends SimpleBeanInfo {
    
  /** Icon for image data objects. */
    private Image icon;

  /** Extended descriptor for this bean. */    
    private BeanDescriptor descriptor;
    
  /** Array of property descriptors. */
    public LuoRudyModel_II_2000BeanInfo() {
        icon = loadImage ("model_cardiac.png");
    }
    
  /** Provides the Models's icon */
    public Image getIcon(int type) {
        return icon;
    }

  /** Provides the Models's descriptor */    
    public BeanDescriptor getBeanDescriptor(){
    	descriptor = new BeanDescriptor(LuoRudyModel_II_2000.class);
    	descriptor.setDisplayName("The Updated Luo-Rudy II Model of Mammalian Ventricular Cardiac Action Potentials, 2000");
    	descriptor.setShortDescription(
    			"The Updated Luo-Rudy II Model of Mammalian Ventricular Cardiac Action Potentials, 2000 <p>" +
    	"Circ Res 1991;68:1501-1526      <br>" +
        "Circ Res 1994;74:1071-1096      <br>" +
        "Circ Res 1994;74:1097-1113      <br>" +
        "Circ Res 1995;77:140-152        <br>" +
        "Biophys J 1995;68:949-964       <br>" +
        "Cardiovasc Res 1997;35:256-272  <br>" +
        "Circulation 1999;99:2466-2474   <br>" +
        "Cardiovas Res 1999;42:530-542   <br>" +
        "Nature 1999;400:566-569         <br>" +
        "Circulation 2000;101:1192-1198  <br>" +
        "Biophy J 2000;78:2392-2404.");
    
        descriptor.setValue("version", "1.4");
    	return descriptor ;
    }        
    
  /** Create a new property descriptor
   * @return Property Descriptor
   */
    private PropertyDescriptor createPropertyDescriptor (String name, String gett, String sett, String group) {
        PropertyDescriptor pd=null;
        try {
            pd = new PropertyDescriptor (name, LuoRudyModel_II_2000.class, gett, sett);
            pd.setShortDescription(group);
        }
        catch (IntrospectionException ex) {}
        return pd;
    }
    
  /** Descriptor of valid properties
   * @return array of properties
   */
    public PropertyDescriptor[] getPropertyDescriptors () {
        PropertyDescriptor[] desc =
        {
            createPropertyDescriptor ("Length of the cell (cm)",  "getl", "setl","Cell Geometry"),
            createPropertyDescriptor ("Radius of the cell (cm)",  "geta", "seta","Cell Geometry"),
            
            createPropertyDescriptor ("Membrane voltage (mV)",  "getv", "setv","Voltage"),
            
            createPropertyDescriptor ("Time step (ms)",  "getdt", "setdt","Time Step"),
            createPropertyDescriptor ("Initial time (ms)",  "gett", "sett","Time Step"),
            
            createPropertyDescriptor ("Stimulus amplitude (uA/cm^2)",  "getst", "setst","Total Current and Stimulus"),
            createPropertyDescriptor ("Time when stimulus is applied (ms)",  "gettstim", "settstim","Total Current and Stimulus"),
            createPropertyDescriptor ("Stimulus duration (ms)",  "getstl", "setstl","Total Current and Stimulus"),
            createPropertyDescriptor ("Total experiment time (ms)",  "getetime", "setetime","Total Current and Stimulus"),
            createPropertyDescriptor ("Basic cycle length (ms)",  "getbcl", "setbcl","Total Current and Stimulus"),
            
            createPropertyDescriptor ("Temperature (K)",  "gettemp", "settemp","Termodynamics"),
            
            createPropertyDescriptor ("Intracellular Na concentration (mM)",  "getnai", "setnai","Ion Concentrations"),
            createPropertyDescriptor ("Extracellular Na concentration (mM)",  "getnao", "setnao","Ion Concentrations"),
            createPropertyDescriptor ("Intracellular K concentration (mM)",  "getki", "setki","Ion Concentrations"),
            createPropertyDescriptor ("Extracellular K concentration (mM)",  "getko", "setko","Ion Concentrations"),
            createPropertyDescriptor ("Intracellular Ca concentration (mM)",  "getcai", "setcai","Ion Concentrations"),
            createPropertyDescriptor ("Extracellular Ca concentration (mM)",  "getcao", "setcao","Ion Concentrations"),
            createPropertyDescriptor ("Calmodulin buffered Ca concentration (mM)",  "getcmdn", "setcmdn","Ion Concentrations"),
            createPropertyDescriptor ("Troponin buffered Ca concentration (mM)",  "gettrpn", "settrpn","Ion Concentrations"),
            createPropertyDescriptor ("NSR Ca concentration (mM)",  "getnsr", "setnsr","Ion Concentrations"),
            createPropertyDescriptor ("JSR Ca concentration (mM)",  "getjsr", "setjsr","Ion Concentrations"),
            createPropertyDescriptor ("Calsequestrin buffered Ca concentration (mM)",  "getcsqn", "setcsqn","Ion Concentrations"),
            createPropertyDescriptor ("Intracellular Mg concentration (mM)",  "getmgi", "setmgi","Ion Concentrations"),
            createPropertyDescriptor ("Intracellular ATP concentration (uM)",  "getatpi", "setatpi","Ion Concentrations"),
            createPropertyDescriptor ("Intracellular ADP concentration (uM)",  "getadpi", "setadpi","Ion Concentrations"),

            createPropertyDescriptor ("Half-saturation concentration of iup (mM)",  "getkmup", "setkmup","NSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. current through iup channel (mM/ms)",  "getiupbar", "setiupbar","NSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. [Ca] in NSR (mM)",  "getnsrbar", "setnsrbar","NSR Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("Time constant of activation of Ca release from JSR (ms)",  "gettauon", "settauon","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Time constant of deactivation of Ca release from JSR (ms)",  "gettauoff", "settauoff","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Threshold for external triggering of Ca release from JSR (mM)",  "getdcaith", "setdcaith","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. rate constant of Ca release from JSR due to CICR (ms^-1)",  "getgrelbarcicr", "setgrelbarcicr","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Half-saturation constant of irel for CICR (mM)",  "getkmrel", "setkmrel","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Threshold for release of Ca from calsequestrin (CSQN) due to JSR overload (mM)",  "getcsqnth", "setcsqnth","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. rate constant of Ca release from JSR due to overload (ms^-1)",  "getgmaxrel", "setgmaxrel","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Rate constant of Ca release from JSR due to overload (ms^-1)",  "getgrelbarjsrol", "setgrelbarjsrol","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. [Ca] buffered in CSQN (mM)",  "getcsqnbar", "setcsqnbar","JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Equalibrium constant of buffering for CSQN (mM)",  "getkmcsqn", "setkmcsqn","JSR Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("Time constant of Ca transfer from NSR to JSR (ms)",  "gettautr", "settautr","Translocation of Ca Ions from NSR to JSR"),
            
            createPropertyDescriptor ("Max. [Ca] buffered in calmodulin (CMDN) (mM)",  "getcmdnbar", "setcmdnbar","Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Max. [Ca] buffered in troponin (TRPN) (mM)",  "gettrpnbar", "settrpnbar","Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Equalibrium constant of buffering for CMDN (mM)",  "getkmcmdn", "setkmcmdn","Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("Equalibrium constant of buffering for TRPN (mM)",  "getkmtrpn", "setkmtrpn","Myoplasmic Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("Scaling factor of the Na current",  "getscgna", "setscgna","Fast Sodium Current (time dependent)"),
            
            createPropertyDescriptor ("Half-saturation concentration of Ca channel (mM)",  "getkmca", "setkmca","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Permiability of membrane to Ca (cm/s)",  "getpca", "setpca","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of Ca in",  "getgacai", "setgacai","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of Ca out",  "getgacao", "setgacao","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Permiability of membrane to Na (cm/s)",  "getpna", "setpna","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of Na in",  "getganai", "setganai","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of Na out",  "getganao", "setganao","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Permiability of membrane to K (cm/s)",  "getpk", "setpk","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of K in",  "getgaki", "setgaki","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Activity coefficient of K out",  "getgako", "setgako","Current through L-type Ca Channel"),
            createPropertyDescriptor ("Scaling factor of the L-type Ca current",  "getscgcal", "setscgcal","Current through L-type Ca Channel"),
            
            createPropertyDescriptor ("Scaling factor of the T-type Ca current",  "getscgcat", "setscgcat","Current through T-type Ca Channel"),
            
            createPropertyDescriptor ("Scaling factor of the rapidly activating K current",  "getscgkr", "setscgkr","Rapidly Activating Potassium Current"),
            
            createPropertyDescriptor ("Na/K permiability ratio",  "getprnak", "setprnak","Slowly Activating Potassium Current"),
            createPropertyDescriptor ("Scaling factor of the slowly activating K current",  "getscgks", "setscgks","Slowly Activating Potassium Current"),
            
            createPropertyDescriptor ("Scaling factor of the time independent K current",  "getscgki", "setscgki","Potassium Current (time-independent)"),
            
            createPropertyDescriptor ("Scaling factor of the plateau K current",  "getscgkp", "setscgkp","Plateau Potassium Current"),
            
            createPropertyDescriptor ("Scaling factor of the Na-Ca exchanger current",  "getknaca", "setknaca","Sodium-Calcium Exchanger"),
            createPropertyDescriptor ("Half-saturation concentration of NaCa exchanger Na (mM)",  "getkmnae", "setkmnae","Sodium-Calcium Exchanger"),
            createPropertyDescriptor ("Half-saturation concentration of NaCa exchanger Ca (mM)",  "getkmcae", "setkmcae","Sodium-Calcium Exchanger"),
            createPropertyDescriptor ("Saturation factor of I Na-Ca at very negative potentials",  "getksat", "setksat","Sodium-Calcium Exchanger"),
            createPropertyDescriptor ("Position of energy barrier controlling voltage dependence of I Na-Ca ",  "getnu", "setnu","Sodium-Calcium Exchanger"),
            
            createPropertyDescriptor ("Max. current through Na-K pump (uA/uF)",  "getibarnak", "setibarnak","Sodium-Potassium Pump"),
            createPropertyDescriptor ("Half-saturation concentration of NaK pump Na (mM)",  "getkmnai", "setkmnai","Sodium-Potassium Pump"),
            createPropertyDescriptor ("Half-saturation concentration of NaK pump K (mM)",  "getkmko", "setkmko","Sodium-Potassium Pump"),
            
            createPropertyDescriptor ("Permiability of membrane to Ca (non-specific) (cm/s)",  "getpnsca", "setpnsca","Nonspecific Ca-activated Current"),
            createPropertyDescriptor ("Half-saturation concentration of NSCa channel (mM)",  "getkmnsca", "setkmnsca","Nonspecific Ca-activated Current"),
            
            createPropertyDescriptor ("Scaling factor of the IKATP current",  "getscgbarkatp", "setscgbarkatp","ATP-sensitive Potassium Current"),
            
            createPropertyDescriptor ("Max. Ca current through sarcolemmal Ca pump (uA/uF)",  "getibarpca", "setibarpca","Sarcolemmal Ca Pump"),
            createPropertyDescriptor ("Half-saturation concentration of sarcolemmal Ca pump (mM)",  "getkmpca", "setkmpca","Sarcolemmal Ca Pump"),
            
            createPropertyDescriptor ("Scaling factor of the Ca background",  "getscgcab", "setscgcab","Ca Background Current"),
            
            createPropertyDescriptor ("Scaling factor of the Na background",  "getscgnab", "setscgnab","Na Background Current"),
          
            
            createPropertyDescriptor ("|OUT Membrane voltage (mV)",  "getv", null,"Voltage"),
            createPropertyDescriptor ("|OUT d voltage / d time (mV/ms)",  "getdvdt", null,"Voltage"),
            
            createPropertyDescriptor ("|OUT Fast Na current (uA/uF)",  "getina", null,"Fast Sodium Current (time dependent)"),
            createPropertyDescriptor ("|OUT Reversal potential of Na (mV)",  "getena", null,"Fast Sodium Current (time dependent)"),
            createPropertyDescriptor ("|OUT Na activation m",  "getm", null,"Fast Sodium Current (time dependent)"),
            createPropertyDescriptor ("|OUT Na inactivation h",  "geth", null,"Fast Sodium Current (time dependent)"),
            createPropertyDescriptor ("|OUT Na inactivation j",  "getj", null,"Fast Sodium Current (time dependent)"),
            
            createPropertyDescriptor ("|OUT Total current through the L-type Ca channel (uA/uF)",  "getilcatot", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Ca current through L-type Ca channel (uA/uF)",  "getilca", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Na current through L-type Ca channel (uA/uF)",  "getilcana", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT K current through L-type Ca channel (uA/uF)",  "getilcak", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Voltage dependent activation gate d",  "getd", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Voltage dependent inactivation gate f",  "getf", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Ca dependent inactivation gate",  "getfca", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Max. Ca current through Ca channel (uA/uF)",  "getibarca", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Max. Na current through Ca channel (uA/uF)",  "getibarna", null,"Current through L-type Ca Channel"),
            createPropertyDescriptor ("|OUT Max. K current through Ca channel (uA/uF)",  "getibark", null,"Current through L-type Ca Channel"),
            
            createPropertyDescriptor ("|OUT Ca current through T-type Ca channel (uA/uF)",  "geticat", null,"Current through T-type Ca Channel"),
            createPropertyDescriptor ("|OUT Reversal potential of the T-type Ca channel (mV)",  "geteca", null,"Current through T-type Ca Channel"),
            createPropertyDescriptor ("|OUT Voltage dependent activation gate b",  "getb", null,"Current through T-type Ca Channel"),
            createPropertyDescriptor ("|OUT Voltage dependent inactivation gate g",  "getg", null,"Current through T-type Ca Channel"),
            
            createPropertyDescriptor ("|OUT Rapidly activating K current (uA/uF)",  "getikr", null,"Rapidly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT Reversal potential of rapidly activating K current (mV)",  "getekr", null,"Rapidly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT Rapidly activating K time-dependent activation",  "getxr", null,"Rapidly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT K time-independent inactivation r",  "getr", null,"Rapidly Activating Potassium Current"),
            
            createPropertyDescriptor ("|OUT Slowly activating K current (uA/uF)",  "getiks", null,"Slowly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT Reversal potential of slowly activating K current (mV)",  "geteks", null,"Slowly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT Slowly activating K time-dependent activation 1",  "getxs1", null,"Slowly Activating Potassium Current"),
            createPropertyDescriptor ("|OUT Slowly activating K time-dependent activation 2",  "getxs2", null,"Slowly Activating Potassium Current"),
            
            createPropertyDescriptor ("|OUT Time-independent K current (uA/uF)",  "getiki", null,"Potassium Current (time-independent)"),
            createPropertyDescriptor ("|OUT Reversal potential of time independent K current (mV)",  "geteki", null,"Potassium Current (time-independent)"),
            createPropertyDescriptor ("|OUT K inactivation",  "getkin", null,"Potassium Current (time-independent)"),
            
            createPropertyDescriptor ("|OUT Plateau K current (uA/uF)",  "getikp", null,"Plateau Potassium Current"),
            createPropertyDescriptor ("|OUT Reversal potential of plateau K current (mV)",  "getekp", null,"Plateau Potassium Current"),
            createPropertyDescriptor ("|OUT K plateau factor",  "getkp", null,"Plateau Potassium Current"),
            
            createPropertyDescriptor ("|OUT Na-Ca exchanger current (uA/uF)",  "getinaca", null,"Sodium-Calcium Exchanger"),
            
            createPropertyDescriptor ("|OUT Na-K pump current (uA/uF)",  "getinak", null,"Sodium-Potassium Pump"),
            createPropertyDescriptor ("|OUT Voltage-dependence parameter of inak",  "getfnak", null,"Sodium-Potassium Pump"),
            
            createPropertyDescriptor ("|OUT Non-specific Na current (uA/uF)",  "getinsna", null,"Nonspecific Ca-activated Current"),
            createPropertyDescriptor ("|OUT Non-specific K current (uA/uF)",  "getinsk", null,"Nonspecific Ca-activated Current"),
            createPropertyDescriptor ("|OUT Max. Na current through NSCa channel (uA/uF)",  "getibarnsna", null,"Nonspecific Ca-activated Current"),
            createPropertyDescriptor ("|OUT Max. K current through NSCa channel (uA/uF)",  "getibarnsk", null,"Nonspecific Ca-activated Current"),
            
            createPropertyDescriptor ("|OUT ATP-sensitive potassium current (uA/uF)",  "getikatp", null,"ATP-sensitive Potassium Current"),
            createPropertyDescriptor ("|OUT Fraction of open KATP channels",  "getfatp", null,"ATP-sensitive Potassium Current"),
            
            createPropertyDescriptor ("|OUT Sarcolemmal Ca pump current (uA/uF)",  "getipca", null,"Sarcolemmal Ca Pump"),
            
            createPropertyDescriptor ("|OUT Ca background current (uA/uF)",  "geticab", null,"Ca Background Current"),
            createPropertyDescriptor ("|OUT Nernst potential for Ca (mV)",  "getecan", null,"Ca Background Current"),
            
            createPropertyDescriptor ("|OUT Na background current (uA/uF)",  "getinab", null,"Na Background Current"),
            createPropertyDescriptor ("|OUT Nernst potential for Na (mV)",  "getenan", null,"Na Background Current"),
            
            createPropertyDescriptor ("|OUT Total current (uA/cm^2)",  "getit", null,"Total Current"),
            createPropertyDescriptor ("|OUT Total Na ion flow (mM/ms)",  "getnaiont", null,"Total Current"),
            createPropertyDescriptor ("|OUT Total K ion flow (mM/ms)",  "getkiont", null,"Total Current"),
            createPropertyDescriptor ("|OUT Total Ca ion flow (mM/ms)",  "getcaiont", null,"Total Current"),
            
            createPropertyDescriptor ("|OUT Intracellular Na concentration (mM)",  "getnai", null,"Myoplasmic Na Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Change in intracellular Na concentration (mM)",  "getdnai", null,"Myoplasmic Na Ion Concentration Changes"),
            
            createPropertyDescriptor ("|OUT Intracellular K concentration (mM)",  "getki", null,"Myoplasmic K Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Change in intracellular K concentration (mM)",  "getdki", null,"Myoplasmic K Ion Concentration Changes"),
            
            createPropertyDescriptor ("|OUT NSR Ca concentration (mM)",  "getnsr", null,"NSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Ca uptake from myo. to NSR (mM/ms)",  "getiup", null,"NSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Ca leakage from NSR to myo. (mM/ms)",  "getileak", null,"NSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Change in [Ca] in the NSR (mM)",  "getdnsr", null,"NSR Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("|OUT JSR Ca concentration (mM)",  "getjsr", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Rate constant of Ca release from JSR due to CICR (ms^-1)",  "getgrelcicr", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Ca release from JSR to myo. due to CICR (mM/ms)",  "getirelcicr", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Rate constant of Ca release from JSR due to JSR overload (ms^-1)",  "getgreljsrol", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Ca release from JSR to myo. due to JSR overload (mM/ms)",  "getireljsrol", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Calsequestrin buffered Ca concentration (mM)",  "getcsqn", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Cumulative Ca entry into the cell 2 ms. after dv/dt max. (mM)",  "getdcaitwo", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT t=0 at time of CICR (ms)",  "gettcicr", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT t=0 at time of JSR overload (ms)",  "gettjsrol", null,"JSR Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Change in [Ca] in the JSR (mM)",  "getdjsr", null,"JSR Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("|OUT Translocation current of Ca ions from NSR to JSR (mM/ms)",  "getitr", null,"Translocation of Ca Ions from NSR to JSR"),
            
            createPropertyDescriptor ("|OUT Intracellular Ca concentration (mM)",  "getcai", null,"Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Total myoplasmic Ca concentration (mM)",  "getcatotal", null,"Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Troponin buffered Ca concentration (mM)",  "gettrpn", null,"Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Calmodulin buffered Ca concentration (mM)",  "getcmdn", null,"Myoplasmic Ca Ion Concentration Changes"),
            createPropertyDescriptor ("|OUT Change in myoplasmic Ca concentration (mM)",  "getdcai", null,"Myoplasmic Ca Ion Concentration Changes"),
            
            createPropertyDescriptor ("Number of iterations",  "getsteps", null,"Time Step"),
        };
        return desc;
    }
}