/*
 * This is part of XmlEditor, a graphical editor for XML files
 * Copyright (C) 2001 CERN - Sebastien Ponce
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contacts :
 *   sebastien.ponce@polytechnique.org
 *   http://lhcb-comp.web.cern.ch/lhcb-comp/
 *   http://www.cern.ch
 */

package ch.cern.lhcb.xmleditor.gui;

import javax.swing.event.TreeExpansionEvent;
import javax.swing.tree.ExpandVetoException;

/**
 * this is an expansion of the default TreeWillExpandListener that allows the
 * expansion of reference. In the case of a reference, the node is dereferenced
 * here. Copyright: Copyright (c) Sebastien Ponce
 * 
 * @author Sebastien Ponce
 */
public class TreeWillExpandListener implements
        javax.swing.event.TreeWillExpandListener {

    /**
     * a pointer on the XmlTree are listening to
     */
    private XmlTree jTree;

    /**
     * constructor
     * 
     * @param jTree a pointer XmlTree we are listening to
     */
    public TreeWillExpandListener(XmlTree jTree) {
        this.jTree = jTree;
    }

    /**
     * called each time a node will expand. Deals with references by replacing
     * them by the dereferenced node before it is expanded.
     * 
     * @param event the TreeExpansionEvent
     * @throws ExpandVetoException prevents the expansion in case the expansion
     *         was actually a dereferencement
     */
    public void treeWillExpand(TreeExpansionEvent event)
            throws ExpandVetoException {
        // first get the treeNode to expand
        XmlTreeNode treeNode = (XmlTreeNode) event.getPath()
                .getLastPathComponent();
        // if references are allowed
        if (treeNode.allowsReferences()) {
            // then try to expand it as a reference
            jTree.undoableExpandReference(treeNode);
            // in the case it was really a reference, the expansion was done
            // and the regular expansion should not take place, so it is vetoed
            if (treeNode.isReference()) { throw new ExpandVetoException(event); }
        }
    }

    /**
     * called each time a tree will collapse. Does nothing.
     * 
     * @param event the TreeExpansionEvent
     * @throws ExpandVetoException never sent
     */
    public void treeWillCollapse(TreeExpansionEvent event)
            throws ExpandVetoException {
        // If some memory management is needed, it has to be done here
    }
}