/*
 * com.simulogic.cese -- Cell Electrophysiology Simulation Environment (CESE)
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 * 
 * Dalhousie Univ., Halifax, NS, Canada
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.cese.signals;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.Vector;

import com.simulogic.cese.ResourceManager;
import com.simulogic.cese.UserHome;

/**
 * This is a class for creating an arbitrary waveform signal
 * <p>
 * 1 parameters for waveform signal:
 * <ol>
 * <li>is a duration
 * </ol>
 */
public class WaveformSignal extends AbstractSignal {

    private Vector waveform;

    /**
     * Creates new waveform signal
     */
    public WaveformSignal() {
        maxParams = 1;
    }

    /**
     * Builds the signal array
     * 
     * @param dt current sampling step, i.e. distance between 2 data points
     * @return resulting array with signal data
     */
    public double[] buildSignal(double dt) {
        double duration;
        double[] result = null;

        try {
            duration = ((Double) parameters.get(0)).doubleValue();

            if (duration <= 0) return result;

            duration = duration / dt;
            int steps = (int) Math.round(duration);
            result = new double[steps];
            int count = 0;

            while ((count < steps) && (count < waveform.size())) {
                result[count] = ((Double) waveform.get(count)).doubleValue();
                count++;
            }
        } catch (Exception e) {
        }
        return result;
    }

    /**
     * Reads and parses an ASCII file with the waveform
     * 
     * @param file waveform file name
     */
    public void setWaveformFile(String file) {
        String filename = "";
        BufferedReader dataReader = null;

        File sFile = new File(file);
        if (!sFile.isAbsolute()) {
            filename = UserHome.CESE_HOME + UserHome.FS
                    + ResourceManager.getResource("recs_dir") + UserHome.FS
                    + sFile.getPath();
        } else {
            filename = sFile.getPath();
        }

        try {
            dataReader = new BufferedReader(new InputStreamReader(
                    new FileInputStream(filename)));

            waveform = new Vector();

            String value = "";

            while ((value = dataReader.readLine()) != null) {
                waveform.add(Double.valueOf(value));
            }

        } catch (IOException e) {
        } finally {
            try {
                if (dataReader != null) dataReader.close();
            } catch (IOException e) {
            }
        }

    }
}