/*
 * com.simulogic.dataview -- The Java2D Plotting Framework
 *
 * Copyright (C) 1999 - 2005 Sergey Missan
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.simulogic.dataview.analysis;

import javax.swing.table.DefaultTableModel;

import com.simulogic.dataview.DataChannel;
import com.simulogic.dataview.DataDesktop;
import com.simulogic.dataview.DataFrame;
import com.simulogic.dataview.DataGroup;
import com.simulogic.dataview.DataStorage;
import com.simulogic.dataview.DataView;
import com.simulogic.dataview.ResourceManager;
import com.simulogic.dataview.ViewContent;
import com.simulogic.dataview.plots.SymbolPlot;

/**
 * Generates dialog box to build a current-voltage relationship (I-V)
 */
public class IVOptions extends javax.swing.JDialog {

    /** A return status code - returned if Cancel button has been pressed */
    public static final int RET_CANCEL = 0;
    /** A return status code - returned if OK button has been pressed */
    public static final int RET_OK = 1;

    private DataDesktop desktop;

    private double xmin;
    private double xmax;

    private ChannelStatsProxy proxy = new ChannelStatsProxy();

    /**
     * Creates new IVOptions
     * 
     * @param parent parent frame
     * @param d desktop
     */
    public IVOptions(java.awt.Frame parent, DataDesktop d) {
        super(parent, true);
        desktop = d;
        initComponents();
    }

    /**
     * @return the return status of this dialog - one of RET_OK or RET_CANCEL
     */
    public int getReturnStatus() {
        return returnStatus;
    }

    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        resButtonGroup = new javax.swing.ButtonGroup();
        buttonPanel = new javax.swing.JPanel();
        okButton = new javax.swing.JButton();
        cancelButton = new javax.swing.JButton();
        viewPanel = new javax.swing.JTabbedPane();
        paramsPanel = new javax.swing.JPanel();
        xPanel = new javax.swing.JPanel();
        xchanLabel = new javax.swing.JLabel();
        xchanTextField = new com.simulogic.utils.IntegerField();
        cursorLabel = new javax.swing.JLabel();
        cursorComboBox = new javax.swing.JComboBox();
        yPanel = new javax.swing.JPanel();
        ychanLabel = new javax.swing.JLabel();
        ychanTextField = new com.simulogic.utils.IntegerField();
        valueLabel = new javax.swing.JLabel();
        valueComboBox = new javax.swing.JComboBox();
        regionLabel = new javax.swing.JLabel();
        regionSelector = new RegionSelector();
        resPanel = new javax.swing.JPanel();
        replaceRadioButton = new javax.swing.JRadioButton();
        appendRadioButton = new javax.swing.JRadioButton();
        selectionScrollPane = new javax.swing.JScrollPane();
        selectionTable = new javax.swing.JTable();

        setTitle(ResourceManager.getResource("Build_I-V"));
        addWindowListener(new java.awt.event.WindowAdapter() {

            public void windowClosing(java.awt.event.WindowEvent evt) {
                closeDialog();
            }
        });

        buttonPanel
                .setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT));

        okButton.setText(ResourceManager.getResource("OK"));
        okButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                okButtonActionPerformed();
            }
        });

        buttonPanel.add(okButton);

        cancelButton.setText(ResourceManager.getResource("Cancel"));
        cancelButton.addActionListener(new java.awt.event.ActionListener() {

            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cancelButtonActionPerformed();
            }
        });

        buttonPanel.add(cancelButton);

        getContentPane().add(buttonPanel, java.awt.BorderLayout.SOUTH);

        paramsPanel.setLayout(new javax.swing.BoxLayout(paramsPanel,
                javax.swing.BoxLayout.Y_AXIS));

        xPanel.setLayout(new java.awt.GridBagLayout());

        xPanel.setBorder(new javax.swing.border.TitledBorder(
                new javax.swing.border.EtchedBorder(), ResourceManager
                        .getResource("X-Axis")));
        xchanLabel.setText(ResourceManager.getResource("Channel_"));
        xchanLabel.setDisplayedMnemonic('c');
        xchanLabel.setLabelFor(xchanTextField);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        xPanel.add(xchanLabel, gridBagConstraints);

        xchanTextField.setText("1");
        xchanTextField.setPositive(true);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 0;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        gridBagConstraints.weightx = 5.0;
        xPanel.add(xchanTextField, gridBagConstraints);

        cursorLabel.setText(ResourceManager.getResource("Value_at_cursor_"));
        cursorLabel.setDisplayedMnemonic('v');
        cursorLabel.setLabelFor(cursorComboBox);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        xPanel.add(cursorLabel, gridBagConstraints);

        cursorComboBox.setModel(new javax.swing.DefaultComboBoxModel(
                new String[] { "1", "2", "3", "4"}));
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        xPanel.add(cursorComboBox, gridBagConstraints);

        paramsPanel.add(xPanel);

        yPanel.setLayout(new java.awt.GridBagLayout());

        yPanel.setBorder(new javax.swing.border.TitledBorder(
                new javax.swing.border.EtchedBorder(), ResourceManager
                        .getResource("Y-Axis")));
        ychanLabel.setText(ResourceManager.getResource("Channel_"));
        ychanLabel.setDisplayedMnemonic('n');
        ychanLabel.setLabelFor(ychanTextField);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        yPanel.add(ychanLabel, gridBagConstraints);

        ychanTextField.setText("2");
        xchanTextField.setPositive(true);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        yPanel.add(ychanTextField, gridBagConstraints);

        valueLabel.setText(ResourceManager.getResource("Value_"));
        valueLabel.setDisplayedMnemonic('u');
        valueLabel.setLabelFor(valueComboBox);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        yPanel.add(valueLabel, gridBagConstraints);

        valueComboBox.setModel(new javax.swing.DefaultComboBoxModel(
                new String[] { ResourceManager.getResource("At_cursor_1"),
                        ResourceManager.getResource("Mean"),
                        ResourceManager.getResource("Positive_peak"),
                        ResourceManager.getResource("Negative_peak"),
                        ResourceManager.getResource("Absolute_peak")}));
        valueComboBox.addItemListener(new java.awt.event.ItemListener() {

            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                valueComboBoxItemStateChanged();
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        yPanel.add(valueComboBox, gridBagConstraints);

        regionLabel.setText(ResourceManager.getResource("Region_"));
        regionLabel.setDisplayedMnemonic('g');
        regionLabel.setLabelFor(regionSelector.getRegionComboBox());
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        yPanel.add(regionLabel, gridBagConstraints);

        regionSelector.getRegionComboBox().setEnabled(false);
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 1;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        gridBagConstraints.anchor = java.awt.GridBagConstraints.EAST;
        yPanel.add(regionSelector.getRegionComboBox(), gridBagConstraints);

        paramsPanel.add(yPanel);

        resPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.LEFT));

        resPanel.setBorder(new javax.swing.border.TitledBorder(
                new javax.swing.border.EtchedBorder(), ResourceManager
                        .getResource("Results")));
        replaceRadioButton.setSelected(true);
        replaceRadioButton.setText(ResourceManager.getResource("Replace"));
        replaceRadioButton.setMnemonic('r');
        resButtonGroup.add(replaceRadioButton);
        resPanel.add(replaceRadioButton);

        appendRadioButton.setText(ResourceManager.getResource("Append"));
        appendRadioButton.setMnemonic('a');
        resButtonGroup.add(appendRadioButton);
        resPanel.add(appendRadioButton);

        paramsPanel.add(resPanel);

        viewPanel
                .addTab(ResourceManager.getResource("Parameters"), paramsPanel);

        selectionScrollPane.setPreferredSize(new java.awt.Dimension(40, 40));

        selectionScrollPane.setViewportView(selectionTable);

        viewPanel.addTab(ResourceManager.getResource("Selection"),
                selectionScrollPane);

        viewPanel.addChangeListener(new javax.swing.event.ChangeListener() {

            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                if (viewPanel.getSelectedIndex() == 1) {
                    fillSelection();
                }

            }
        });

        getContentPane().add(viewPanel, java.awt.BorderLayout.CENTER);
    }

    private void valueComboBoxItemStateChanged() {
        regionSelector.getRegionComboBox().setEnabled(
                !(valueComboBox.getSelectedIndex() == 0));
    }

    private void okButtonActionPerformed() {
		com.simulogic.utils.SwingWorker worker = new com.simulogic.utils.SwingWorker() {

			DataStorage source, result;

			DataChannel xres, yres;

			DataFrame ifr;

			ViewContent iv;

			public Object construct() {
				doClose(RET_OK);

				com.simulogic.dataview.DataChannel xchannel = null;
				com.simulogic.dataview.DataChannel xychannel = null;
				com.simulogic.dataview.DataChannel yychannel = null;

				ifr = desktop.getActiveFrame();
				if (ifr != null) {
					DataView view = ifr.getDataContent().getView();
					source = view.getStorage();

					double r[] = regionSelector.getLimits(view);
					xmin = r[0];
					xmax = r[1];

					String inf = "";

					inf = "Cursor " + cursorComboBox.getSelectedItem()
							+ ", Channel " + xchanTextField.getValue();

					xres = new DataChannel(inf, source.getGroupsSize());

					if (valueComboBox.getSelectedIndex() == 0) {
						inf = valueComboBox.getSelectedItem() + " ";
					} else {
						inf = valueComboBox.getSelectedItem()
								+ " "
								+ regionSelector.getRegionComboBox()
										.getSelectedItem();
					}
					inf = inf + ", Channel " + ychanTextField.getValue();

					yres = new DataChannel(inf, source.getGroupsSize());

					try {
						for (int i = 0; i < source.getGroupsSize(); i++) {
							DataGroup group = source.getGroup(i);
							xchannel = source
									.getChannel(i, group.getXChannel());
							xychannel = source.getChannel(i, xchanTextField
									.getValue());
							yychannel = source.getChannel(i, ychanTextField
									.getValue());

							if ((xchannel != null) && (xychannel != null)
									&& (yychannel != null)
									&& (xychannel.getAttribute().isNormal())
									&& (yychannel.getAttribute().isNormal())) {
								if (i == 0)
									xres.setUnits(xychannel.getUnits());

								xres.setData(i, ChannelStats.getValueAtX(view
										.getCursors().getCursorSlider()
										.getValueAt(
												cursorComboBox
														.getSelectedIndex()),
										xchannel, xychannel));

								if (i == 0)
									yres.setUnits(yychannel.getUnits());

								if (valueComboBox.getSelectedIndex() == 0) {
									// Value at Cursor 1
									yres.setData(i, ChannelStats.getValueAtX(
											view.getCursors().getCursorSlider()
													.getValueAt(0), xchannel,
											yychannel));
								} else {
									yres.setData(i, getStat(valueComboBox
											.getSelectedIndex(), xchannel,
											yychannel));
								}
							}
						}
					} catch (Exception e) {
					}
				}
				return ResourceManager.getResource("Done");
			}

			public void finished() {
				iv = ifr.getIVContent();
				if ((iv == null) || replaceRadioButton.isSelected()) {
					iv = new ViewContent();
					ifr.setIVContent(iv);
				}

				result = iv.getStorage();

				int gp = result.getGroupsSize();
				DataGroup group = new DataGroup(ResourceManager
						.getResource("IV")
						+ " " + gp, "");
				yres.setPlot(new SymbolPlot());
				group.addChannel(xres);
				group.addChannel(yres);

				iv.setVisible(true);
				result.addGroup(group);

				ifr.setSelectedContent(iv);

				desktop.getTasks().removeTask(ResourceManager.getResource("Build_I-V"));
			}
		};
		desktop.getTasks().addTask(ResourceManager.getResource("Build_I-V"));
		worker.start();
	}

    private void fillSelection() {
        DataFrame ifr = desktop.getActiveFrame();
        DataStorage source = ifr.getDataContent().getView().getStorage();
        Object[][] dat = new Object[source.getGroupsSize()][3];
        for (int i = 0; i < source.getGroupsSize(); i++) {
            dat[i][0] = "" + i;
            try {
                if (!source.getChannel(i, xchanTextField.getValue())
                        .getAttribute().isNormal())
                        throw new NullPointerException();
                dat[i][1] = source.getChannel(i, xchanTextField.getValue())
                        .getName();
            } catch (Exception e) {
                dat[i][1] = "--";
            }

            try {
                if (!source.getChannel(i, ychanTextField.getValue())
                        .getAttribute().isNormal())
                        throw new NullPointerException();
                dat[i][2] = source.getChannel(i, ychanTextField.getValue())
                        .getName();
            } catch (Exception e) {
                dat[i][2] = "--";
            }

        }

        selectionTable.setModel(new DefaultTableModel(dat, new String[] {
                ResourceManager.getResource("Sweep"),
                ResourceManager.getResource("X-Axis"),
                ResourceManager.getResource("Y-Axis")}));
    }

    private double getStat(int type, DataChannel xchannel, DataChannel ychannel) {

        proxy.clear();

        if (type == 1) return proxy.getMean(xmin, xmax, xchannel, ychannel);
        if (type == 2)
                return proxy.getPositivePeak(xmin, xmax, xchannel, ychannel);
        if (type == 3)
                return proxy.getNegativePeak(xmin, xmax, xchannel, ychannel);
        if (type == 4)
                return proxy.getAbsolutePeak(xmin, xmax, xchannel, ychannel);
        return 0.0;
    }

    private void cancelButtonActionPerformed() {
        doClose(RET_CANCEL);
    }

    /** Closes the dialog */
    private void closeDialog() {
        doClose(RET_CANCEL);
    }

    private void doClose(int retStatus) {
        returnStatus = retStatus;
        setVisible(false);
        dispose();
    }

    private javax.swing.JComboBox valueComboBox;
    private javax.swing.JRadioButton appendRadioButton;
    private javax.swing.JPanel buttonPanel;
    private com.simulogic.utils.IntegerField xchanTextField;
    private javax.swing.JLabel valueLabel;
    private javax.swing.JPanel yPanel;
    private javax.swing.JLabel regionLabel;
    private javax.swing.JPanel xPanel;
    private javax.swing.JButton okButton;
    private javax.swing.JButton cancelButton;
    private javax.swing.JComboBox cursorComboBox;
    private javax.swing.JPanel paramsPanel;
    private javax.swing.JLabel xchanLabel;
    private com.simulogic.utils.IntegerField ychanTextField;
    private javax.swing.JLabel ychanLabel;
    private javax.swing.JTable selectionTable;
    private javax.swing.ButtonGroup resButtonGroup;
    private javax.swing.JLabel cursorLabel;
    private RegionSelector regionSelector;
    private javax.swing.JPanel resPanel;
    private javax.swing.JScrollPane selectionScrollPane;
    private javax.swing.JTabbedPane viewPanel;
    private javax.swing.JRadioButton replaceRadioButton;
    private int returnStatus = RET_CANCEL;

    /**
     * Overrides setVisible(boolean b) in <code>JDialog</code>
     */
    public void setVisible(boolean b) {
        if (b == true) {
            setResizable(true);
            pack();
            setResizable(false);
            getRootPane().setDefaultButton(okButton);
            setLocationRelativeTo(getOwner());
        }
        super.setVisible(b);
    }

}